@@ -3,8 +3,9 @@ Main interface for networkmanager service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.networkmanager import (
+    from mypy_boto3_networkmanager import (
         Client,
         DescribeGlobalNetworksPaginator,
         GetCustomerGatewayAssociationsPaginator,
@@ -14,7 +15,7 @@ Usage::
         GetSitesPaginator,
         GetTransitGatewayRegistrationsPaginator,
         NetworkManagerClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -28,6 +29,7 @@ Usage::
     get_links_paginator: GetLinksPaginator = client.get_paginator("get_links")
     get_sites_paginator: GetSitesPaginator = client.get_paginator("get_sites")
     get_transit_gateway_registrations_paginator: GetTransitGatewayRegistrationsPaginator = client.get_paginator("get_transit_gateway_registrations")
+    ```
 """
 from mypy_boto3_networkmanager.client import NetworkManagerClient as Client, NetworkManagerClient
 from mypy_boto3_networkmanager.paginator import (
